@@ -29,15 +29,9 @@ logger = logging.getLogger(name=__name__)
 
 _sql_api_version: str = "v1beta4"
 
-# default_refresh_buffer is the amount of time before a refresh's result expires
+# _refresh_buffer is the amount of time before a refresh's result expires
 # that a new refresh operation begins.
-_default_refresh_buffer: int = 5 * 60  # 5 minutes
-
-# _iam_auth_refresh_buffer is the amount of time before a refresh's result expires
-# that a new refresh operation begins when IAM DB AuthN is enabled. Because token
-# sources may be cached until ~60 seconds before expiration, this value must be smaller
-# than default_refresh_buffer.
-_iam_auth_refresh_buffer: int = 55  # seconds
+_refresh_buffer: int = 4 * 60  # 4 minutes
 
 
 async def _get_metadata(
@@ -45,6 +39,7 @@ async def _get_metadata(
     sqladmin_api_endpoint: str,
     credentials: Credentials,
     project: str,
+    region: str,
     instance: str,
 ) -> Dict[str, Any]:
     """Requests metadata from the Cloud SQL Instance
@@ -65,6 +60,9 @@ async def _get_metadata(
     :param project:
         A string representing the name of the project.
 
+    :type region: str
+    :param region : A string representing the name of the region.
+
     :type instance: str
     :param instance: A string representing the name of the instance.
 
@@ -83,6 +81,8 @@ async def _get_metadata(
         )
     elif not isinstance(project, str):
         raise TypeError(f"project must be of type str, got {type(project)}")
+    elif not isinstance(region, str):
+        raise TypeError(f"region must be of type str, got {type(region)}")
     elif not isinstance(instance, str):
         raise TypeError(f"instance must be of type str, got {type(instance)}")
 
@@ -91,18 +91,21 @@ async def _get_metadata(
         credentials.refresh(request)
 
     headers = {
-        "Authorization": "Bearer {}".format(credentials.token),
+        "Authorization": f"Bearer {credentials.token}",
     }
 
-    url = "{}/sql/{}/projects/{}/instances/{}/connectSettings".format(
-        sqladmin_api_endpoint, _sql_api_version, project, instance
-    )
+    url = f"{sqladmin_api_endpoint}/sql/{_sql_api_version}/projects/{project}/instances/{instance}/connectSettings"
 
     logger.debug(f"['{instance}']: Requesting metadata")
 
     resp = await client_session.get(url, headers=headers, raise_for_status=True)
     ret_dict = await resp.json()
 
+    if ret_dict["region"] != region:
+        raise ValueError(
+            f'[{project}:{region}:{instance}]: Provided region was mismatched - got region {region}, expected {ret_dict["region"]}.'
+        )
+
     metadata = {
         "ip_addresses": {ip["type"]: ip["ipAddress"] for ip in ret_dict["ipAddresses"]},
         "server_ca_cert": ret_dict["serverCaCert"]["cert"],
@@ -144,7 +147,8 @@ async def _get_ephemeral(
 
     :type enable_iam_auth: bool
     :param enable_iam_auth
-        Enables IAM based authentication for Postgres instances.
+        Enables automatic IAM database authentication for Postgres or MySQL
+        instances.
 
     :rtype: str
     :returns: An ephemeral certificate from the Cloud SQL instance that allows
@@ -175,9 +179,7 @@ async def _get_ephemeral(
         "Authorization": f"Bearer {credentials.token}",
     }
 
-    url = "{}/sql/{}/projects/{}/instances/{}:generateEphemeralCert".format(
-        sqladmin_api_endpoint, _sql_api_version, project, instance
-    )
+    url = f"{sqladmin_api_endpoint}/sql/{_sql_api_version}/projects/{project}/instances/{instance}:generateEphemeralCert"
 
     data = {"public_key": pub_key}
 
@@ -197,29 +199,28 @@ async def _get_ephemeral(
 
 def _seconds_until_refresh(
     expiration: datetime.datetime,
-    enable_iam_auth: bool,
 ) -> int:
     """
-    Helper function to get time in seconds before performing next refresh.
+    Calculates the duration to wait before starting the next refresh.
+
+    Usually the duration will be half of the time until certificate
+    expiration.
 
     :rtype: int
     :returns: Time in seconds to wait before performing next refresh.
     """
-    if enable_iam_auth:
-        refresh_buffer = _iam_auth_refresh_buffer
-    else:
-        refresh_buffer = _default_refresh_buffer
 
-    delay = (expiration - datetime.datetime.now()) - datetime.timedelta(
-        seconds=refresh_buffer
-    )
+    duration = int((expiration - datetime.datetime.now()).total_seconds())
 
-    if delay.total_seconds() < 0:
-        # If the time until the certificate expires is less than the buffer,
-        # schedule the refresh closer to the expiration time
-        delay = (expiration - datetime.datetime.now()) - datetime.timedelta(seconds=5)
+    # if certificate duration is less than 1 hour
+    if duration < 3600:
+        # something is wrong with certificate, refresh now
+        if duration < _refresh_buffer:
+            return 0
+        # otherwise wait until 4 minutes before expiration for next refresh
+        return duration - _refresh_buffer
 
-    return int(delay.total_seconds())
+    return duration // 2
 
 
 async def _is_valid(task: asyncio.Task) -> bool:
